@@ -1,8 +1,10 @@
 use super::*;
 
-pub(crate) fn render_base<X: PlotNum, Y: PlotNum>(
+pub fn render_base<X: PlotNum, Y: PlotNum>(
     writer: impl std::fmt::Write,
-    extra: &Extra<X, Y>,
+    boundx: &DataBound<X>,
+    boundy: &DataBound<Y>,
+    canvas: &Canvas,
     base: impl BaseFmtAndTicks<X = X, Y = Y>,
 ) -> std::fmt::Result {
     let mut writer = tagger::new(writer);
@@ -14,13 +16,14 @@ pub(crate) fn render_base<X: PlotNum, Y: PlotNum>(
         paddingy,
         xaspect_offset,
         yaspect_offset,
-        scalex,
-        scaley,
         ..
-    } = extra.canvas;
+    } = canvas;
 
-    let boundx = [extra.boundx.min, extra.boundx.max];
-    let boundy = [extra.boundy.min, extra.boundy.max];
+    let scalex = canvas.boundx.max;
+    let scaley = canvas.boundy.max;
+
+    let boundx = [boundx.min, boundx.max];
+    let boundy = [boundy.min, boundy.max];
 
     let [minx, maxx] = boundx;
     let [miny, maxy] = boundy;
@@ -139,7 +142,7 @@ pub(crate) fn render_base<X: PlotNum, Y: PlotNum>(
                 d.attr("y2", yaspect_offset + height - paddingy * 0.95)
             })?;
 
-            if extra.xtick_lines {
+            if canvas.xtick_lines {
                 writer.single("line", |d| {
                     d.attr("class", "poloto_tick_line")?;
                     d.attr("stroke", "black")?;
@@ -192,7 +195,7 @@ pub(crate) fn render_base<X: PlotNum, Y: PlotNum>(
                 d.attr("y2", yaspect_offset + yy)
             })?;
 
-            if extra.ytick_lines {
+            if canvas.ytick_lines {
                 writer.single("line", |d| {
                     d.attr("class", "poloto_tick_line")?;
                     d.attr("stroke", "black")?;
